@@ -1,4 +1,4 @@
-// $Id: VParse.cpp 52657 2008-03-31 21:40:18Z wsnyder $  -*- C++ -*-
+// -*- C++ -*-
 //*************************************************************************
 //
 // Copyright 2000-2008 by Wilson Snyder.  This program is free software;
@@ -16,17 +16,18 @@
 ///
 /// Authors: Wilson Snyder
 ///
-/// Code available from: http://www.veripool.com/verilog-perl
+/// Code available from: http://www.veripool.org/verilog-perl
 ///
 //*************************************************************************
 
-#include <stdio.h>
+#include <cstdio>
+#include <cstring>
 #include <fstream>
 #include <stack>
 #include <vector>
 #include <map>
 #include <deque>
-#include <assert.h>
+#include <cassert>
 
 #include "VParse.h"
 #include "VParseLex.h"
